==> table-linker-0.1.tar.gz: table-linker-0.1/tl/cli/get-phrase-matches.py <==
import sys
import argparse
import traceback
import tl.exceptions


def parser():
    return {
        'help': 'retrieves the identifiers of KG entities base on phrase match queries.'
    }


def add_arguments(parser):
    """
    Parse Arguments
    Args:
        parser: (argparse.ArgumentParser)

    """

    parser.add_argument('-c', '--column', action='store', type=str, dest='column', required=True,
                        help='the column used for retrieving candidates.')

    parser.add_argument('-p', '--properties', action='store', type=str, dest='properties', default='labels^2,aliases',
                        help='a comma separated names of properties in the KG to search for exact match query')

    parser.add_argument('-n', action='store', type=int, dest='size', default=50,
                        help='maximum number of candidates to retrieve')

    parser.add_argument('input_file', nargs='?', type=argparse.FileType('r'), default=sys.stdin)

    # used for filtering
    parser.add_argument('--filter', action='store', nargs='?', dest='filter_condition',
                        default=None, help="If set to run filtering, which kind of the data should keep.")


def run(**kwargs):
    from tl.candidate_generation import phrase_query_candidates
    import pandas as pd
    try:
        df = pd.read_csv(kwargs['input_file'], dtype=object)

        em = phrase_query_candidates.PhraseQueryMatches(es_url=kwargs['url'], es_index=kwargs['index'],
                                                        es_user=kwargs['user'],
                                                        es_pass=kwargs['password'])
        odf = em.get_phrase_matches(kwargs['column'], properties=kwargs['properties'], size=kwargs['size'], 
                                    df=df, filter_condition=kwargs['filter_condition'])
        
        odf.to_csv(sys.stdout, index=False)
    except:
        message = 'Command: get-phrase-matches\n'
        message += 'Error Message:  {}\n'.format(traceback.format_exc())
        raise tl.exceptions.TLException(message)

==> table-linker-0.8.tar.gz: table-linker-0.8/tl/cli/get-phrase-matches.py <==
import sys
import argparse
import traceback
import tl.exceptions
from tl.utility.logging import Logger


def parser():
    return {
        'help': 'retrieves the identifiers of KG entities base on phrase match queries.'
    }


def add_arguments(parser):
    """
    Parse Arguments
    Args:
        parser: (argparse.ArgumentParser)

    """

    parser.add_argument('-c', '--column', action='store', type=str, dest='column', required=True,
                        help='the column used for retrieving candidates.')

    parser.add_argument('-p', '--properties', action='store', type=str, dest='properties', default='labels^2,aliases',
                        help='a comma separated names of properties in the KG to search for exact match query')

    parser.add_argument('-n', action='store', type=int, dest='size', default=50,
                        help='maximum number of candidates to retrieve')

    parser.add_argument('-o', '--output-column', action='store', type=str, dest='score_column_name', default="retrieval_score",
                        help='the output column name where the normalized scores will be stored.Default is retrieval_score')

    parser.add_argument('--previous-match-column-name', action='store', type=str, dest='previous_match_column_name',
                        default="retrieval_score",
                        help='the output column name of previous match results')

    parser.add_argument('input_file', nargs='?', type=argparse.FileType('r'), default=sys.stdin)

    # used for filtering
    parser.add_argument('--filter', action='store', nargs='?', dest='filter_condition',
                        default=None, help="If set to run filtering, which kind of the data should keep.")


def run(**kwargs):
    from tl.candidate_generation import phrase_query_candidates
    import pandas as pd
    import time
    try:
        df = pd.read_csv(kwargs['input_file'], dtype=object)
        start = time.time()
        em = phrase_query_candidates.PhraseQueryMatches(es_url=kwargs['url'], es_index=kwargs['index'],
                                                        es_user=kwargs['user'],
                                                        es_pass=kwargs['password'],
                                                        score_column_name=kwargs["score_column_name"],
                                                        previous_match_column_name=kwargs["previous_match_column_name"])

        odf = em.get_phrase_matches(kwargs['column'], properties=kwargs['properties'], size=kwargs['size'],
                                    df=df, filter_condition=kwargs['filter_condition'])
        end = time.time()
        logger = Logger(kwargs["logfile"])
        logger.write_to_file(args={
            "command": "get-phrase-matches",
            "time": end-start
        })
        odf.to_csv(sys.stdout, index=False)
    except:
        message = 'Command: get-phrase-matches\n'
        message += 'Error Message:  {}\n'.format(traceback.format_exc())
        raise tl.exceptions.TLException(message)
